write_command

Function write_command 

pub unsafe fn write_command(out: *mut PmpxCommand, spec: CommandSpec)
Write a CommandSpec in its cross-boundary form, with the memory allocated by this side.

Safety

out must point at writable memory for a PmpxCommand.